#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_skin.interfaces.viewlet import IToolbarViewletManager
from pyams_skin.layer import IPyAMSLayer
from pyams_workflow.interfaces import IWorkflowVersion, IWorkflowState, IWorkflowVersions, IWorkflowManagedContent, \
    IWorkflow

# import packages
from pyams_template.template import template_config
from pyams_utils.registry import get_utility
from pyams_utils.traversing import get_parent
from pyams_viewlet.viewlet import viewlet_config, Viewlet
from pyramid.decorator import reify


@viewlet_config(name='pyams_workflow.versions', context=IWorkflowVersion, layer=IPyAMSLayer,
                manager=IToolbarViewletManager, weight=1)
@template_config(template='templates/versions.pt', layer=IPyAMSLayer)
class WorkflowVersionMenuProvider(Viewlet):
    """Workflow versions menu content provider"""

    @reify
    def workflow(self):
        content = get_parent(self.context, IWorkflowManagedContent)
        return get_utility(IWorkflow, name=content.workflow_name)

    def get_workflow_state(self, context=None):
        if context is None:
            context = self.context
        state = IWorkflowState(context)
        return {'version': state.version_id,
                'state': state.state,
                'state_label': self.request.localizer.translate(self.workflow.get_state_label(state.state))}

    @property
    def workflow_versions(self):
        return IWorkflowVersions(self.context).get_last_versions(count=0)
